@@ -4,6 +4,3 @@ django_adtools/__init__.py
 __author__ = 'shmakovpn <shmakovpn@yandex.ru>'
 __date__ = '2020-06-05'
 
-
-from . import dns
-from . import ad
